@@ -9,7 +9,7 @@ from .utilities import clear_cache  # noqa
 
 try:
     from importlib.metadata import version
-except ImportError:
+except ImportError:  # pragma: no cover
     from importlib_metadata import version  # type: ignore
 
 # Initialize version string from package metadata
